'use strict';

var web3_js = require('@solana/web3.js');
var web3_jsNext = require('@solana/web3.js-next');

// src/instructions.ts
function fromIInstructionToTransactionInstruction(instruction) {
  const keys = !instruction.accounts ? [] : instruction.accounts.map(({ address: address2, role }) => {
    return {
      pubkey: new web3_js.PublicKey(address2),
      isSigner: role == web3_jsNext.AccountRole.READONLY_SIGNER || role == web3_jsNext.AccountRole.WRITABLE_SIGNER,
      isWritable: role == web3_jsNext.AccountRole.WRITABLE || role == web3_jsNext.AccountRole.WRITABLE_SIGNER
    };
  });
  const programId = new web3_js.PublicKey(instruction.programAddress);
  const data = instruction.data ? Buffer.from(instruction.data) : Buffer.alloc(0);
  return new web3_js.TransactionInstruction({
    keys,
    programId,
    data
  });
}
function fromTransactionInstructionToIInstruction(instruction) {
  const accounts = instruction.keys.map((key) => {
    return {
      address: web3_jsNext.address(key.pubkey.toString()),
      role: Number(key.isSigner) << 1 | Number(key.isWritable)
      // 2 bits - Writable LSB, Signer MSB
    };
  });
  const data = new Uint8Array(instruction.data);
  const programAddress = web3_jsNext.address(instruction.programId.toString());
  return {
    accounts,
    programAddress,
    data
  };
}
function fromConnectionToRpc(connection) {
  const connectionTransport = connection._rpcClient;
  const connectionCommitment = connection._commitment;
  const transport = async ({ payload }) => await new Promise((resolve, reject) => {
    const { method, params } = payload;
    connectionTransport.request(
      method,
      params,
      (err, result) => {
        if (err) {
          reject(err);
        }
        resolve(result);
      }
    );
  });
  return web3_jsNext.createRpc({
    api: web3_jsNext.createSolanaRpcApi({
      ...DEFAULT_RPC_CONFIG,
      defaultCommitment: connectionCommitment
    }),
    transport
  });
}
function createSolanaJsonRpcIntegerOverflowError(methodName, keyPath, value) {
  let argumentLabel = "";
  if (typeof keyPath[0] === "number") {
    const argPosition = keyPath[0] + 1;
    const lastDigit = argPosition % 10;
    const lastTwoDigits = argPosition % 100;
    if (lastDigit == 1 && lastTwoDigits != 11) {
      argumentLabel = argPosition + "st";
    } else if (lastDigit == 2 && lastTwoDigits != 12) {
      argumentLabel = argPosition + "nd";
    } else if (lastDigit == 3 && lastTwoDigits != 13) {
      argumentLabel = argPosition + "rd";
    } else {
      argumentLabel = argPosition + "th";
    }
  } else {
    argumentLabel = `\`${keyPath[0].toString()}\``;
  }
  const path = keyPath.length > 1 ? keyPath.slice(1).map(
    (pathPart) => typeof pathPart === "number" ? `[${pathPart}]` : pathPart
  ).join(".") : void 0;
  const error = new web3_jsNext.SolanaError(web3_jsNext.SOLANA_ERROR__RPC__INTEGER_OVERFLOW, {
    argumentLabel,
    keyPath,
    methodName,
    optionalPathLabel: path ? ` at path \`${path}\`` : "",
    value,
    ...path !== void 0 ? { path } : void 0
  });
  web3_jsNext.safeCaptureStackTrace(error, createSolanaJsonRpcIntegerOverflowError);
  return error;
}
var DEFAULT_RPC_CONFIG = {
  defaultCommitment: "confirmed",
  onIntegerOverflow(methodName, keyPath, value) {
    throw createSolanaJsonRpcIntegerOverflowError(methodName, keyPath, value);
  }
};

exports.fromConnectionToRpc = fromConnectionToRpc;
exports.fromIInstructionToTransactionInstruction = fromIInstructionToTransactionInstruction;
exports.fromTransactionInstructionToIInstruction = fromTransactionInstructionToIInstruction;
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.js.map